.. _tobiko-installation-guide:

=======
Install
=======

This document describes how to setup an environment for running test cases


.. sidebar:: See also

    For a quick and simpler start you can jump to the
    :ref:`tobiko-quick-start-guide`.

    To configure Tobiko please read :ref:`tobiko-configuration-guide`.

    To run Tobiko scenario test cases please look at
    :ref:`tobiko-test-case-execution-guide`.


.. include:: _install_venv.rst


What's Next
-----------

To know how to configure Tobiko please read :ref:`tobiko-configuration-guide`.
